Flask-Moment
============

[![Build status](https://github.com/miguelgrinberg/flask-moment/workflows/build/badge.svg)](https://github.com/miguelgrinberg/flask-moment/actions) [![codecov](https://codecov.io/gh/miguelgrinberg/flask-moment/branch/main/graph/badge.svg)](https://codecov.io/gh/miguelgrinberg/flask-moment)

This extension enhances Jinja2 templates with formatting of dates and times
using [moment.js](https://momentjs.com/).

Resources
---------

-  [Documentation](http://flask-moment.readthedocs.io/en/latest/)
-  [PyPI](https://pypi.python.org/pypi/flask-moment)
-  [Change Log](https://github.com/miguelgrinberg/flask-moment/blob/main/CHANGES.md)
